.. _tutorials:

********************
Developer Tutorials
********************

The QONNX repository provides several Jupyter notebooks tutorials.
These can help new developers get up-to-speed on QONNX internals.
All Jupyter notebooks can be found under the `notebook folder <https://github.com/fastmachinelearning/qonnx/tree/main/notebooks>`_.


* 0_how_to_work_with_onnx

  * This notebook can help you to learn how to create and manipulate a simple ONNX model, also by using QONNX

* 1_custom_analysis_pass

  * Explains what an analysis pass is and how to write one for QONNX.

* 2_custom_transformation_pass

  * Explains what a transformation pass is and how to write one for QONNX.

* 3_custom_op

  * Explains the basics of QONNX custom ops and how to define a new one.
